<?php
namespace Teknisa\FIS\Modules\Acessorias\Controllers;

use Doctrine\ORM\EntityManager;
use Teknisa\FIS\Modules\Acessorias\Services\Fis11000CompraLegalBaService;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response\Error;

class Fis11000CompraLegalBaController 
{
    protected $compraLegalBaService;
    
    public function __construct(EntityManager $entityManager, Fis11000CompraLegalBaService $compraLegalBaService){
        $this->entityManager        = $entityManager;
        $this->compraLegalBaService = $compraLegalBaService;
        set_time_limit(0);
    }
     
    /**
     * Função para realizar a exportação Compra LEGAL - BA
     */
    public function exportarCompraLegalBa(DTO\Request $request, DTO\Response $response) {
        try {
            $rows = $request->getRow();
            
            $row['NRORG'] = $rows["filter"]["NRORG"];
            $row['NRLISTA'] = $rows["nrlista"];
            $row['CDEMPRESA'] = $rows["header"]["CDEMPRESA"];
            $row['CDIMPOSTO'] = $rows["header"]["CDIMPOSTONFE"];
            $row['CDINSCESTA'] = $rows["inscrestad"];
            $row['DTINICIAL'] = $rows["filter"]["P_DTINICIAL"];
            $row['DTFINAL'] = $rows["filter"]["P_DTFINAL"];
            
            $row["NMARQUIVO"] = $rows["header"]["NMARQUIVO"].' Empresa: '.$row['CDEMPRESA'].' Insc Estadual: '.$row['CDINSCESTA'];//str_replace(' ', '', $row["NMARQUIVO"]);
            
            // Chama a função de validação
            $fileName = $this->compraLegalBaService->exportarCompraLegalBa($row);
            
            // Retorna o nome do arquivo
            $response->addDataset(new DataSet('columnsToReturn', ["fileName" => $fileName]));
            
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    } 
    
    public function findAgendamento(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            
            $rows = $this->compraLegalBaService->findAgendamento();
            
            $dataSet = new DataSet('agendobrigacess_fis11000', $rows);
            $response->setDataSets(array($dataSet));
            
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    } 
    
    public function saveAgendamento(DTO\Request $request, DTO\Response $response) {
        try {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            
            $row = $request->getRow();
            
            // Chama a função de validação.
            $fileName = $this->compraLegalBaService->saveAgendamento($row);
            
            $this->entityManager->commit();

            // Retorna o nome do arquivo exportado.
            $response->addDataset(new DataSet('columnsToReturn', array("fileName" => $fileName)));
        } catch(\Exception $e) {
            $this->entityManager->rollback();
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function deleteAgendamento(DTO\Request $request, DTO\Response $response) {
        try {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            
            $row = $request->getRow();
            
            // Chama a função de validação.
            $this->compraLegalBaService->deleteAgendamento($row);
            
            $this->entityManager->commit();

        } catch(\Exception $e) {
            $this->entityManager->rollback();
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function execAgendamentoCompraLegalBa(DTO\Request $request, DTO\Response $response) {
        try {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            
            $row = $request->getParameters();
            
            $this->compraLegalBaService->execAgendamento($row);
            
            $this->entityManager->commit();

        } catch(\Exception $e) {
            $this->entityManager->rollback();
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function saveListaCompraLegalBa(DTO\Request $request, DTO\Response $response) {
        try {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            
            $rows = $request->getDataSet()->getRows();
            
            $nrlista = $this->compraLegalBaService->saveListaCompraLegalBa($rows);
            
            $this->entityManager->commit();
            
            $response->addDataset(new DataSet('columnsToReturn', ['NRLISTA' => $nrlista]));

        } catch(\Exception $e) {
            $this->entityManager->rollback();
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function deleteListaCompraLegalBa(DTO\Request $request, DTO\Response $response) {
        try {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            
            $row = $request->getRow();
            
            $this->compraLegalBaService->deleteListaCompraLegalBa($row);
            
            $this->entityManager->commit();
            
        } catch(\Exception $e) {
            $this->entityManager->rollback();
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
}