<?php
namespace Teknisa\FIS\Modules\Acessorias\Services;

use Teknisa\FIS\Modules\Acessorias\Factories\Fis47000Sef2Factory;
use Teknisa\FIS\Modules\Acessorias\Services\Fis91000ObrigacoesAcessoriasService;
use Teknisa\FIS\Modules\Acessorias\Services\Agendamento;

use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\DateUtil;
use Teknisa\Libs\Util\NewCode;
use \Teknisa\Libs\Util\Libraries\PHPMailer;

class Fis47000Sef2Service
{
    protected $environment;
    protected $sef2Factory;
    protected $obrigacoesService;
    
    public $mensagemBody = '';
    public $mensagemBodySucess = '';
    public $mensagemError = '';
    public $mensagemErrorBody = '';
    public $geraArquivo = '';

    public function __construct(Environment $environment, Fis47000Sef2Factory $sef2Factory, Fis91000ObrigacoesAcessoriasService $obrigacoesService,
                                    NewCode $newCode, Agendamento $agendamento )
    {
        $this->environment = $environment;
        $this->sef2Factory = $sef2Factory;
        $this->obrigacoesService = $obrigacoesService;
        $this->newCode                  = $newCode;
        $this->agendamento           = $agendamento;
    }

    /**
     * Função para criar o arquivo da exportação SEF-2
     */
    /*private function createFileSef2($row)
    {
        // Cria os parâmetros para buscar os dados gerados na procedure.
        $params = [
            'NRORG' => $row['NRORG'],
            'NRSEQARQMAG' => $row['NRSEQARQMAG'],
        ];
        //$sef2Data = $this->sef2Factory->getSef2FiscalData($params);
        $sef2Data = $this->sef2Factory->getSef2FiscalDataPeriod($params);

        if(isset($row['NRAGENDAMENTO']) && empty($sef2Data)){
            $this->mensagemError = '<br />'."Não há dados a serem exibidos.";
            return $fileName = false;
        } else if(empty($sef2Data)){
            throw new \Exception("Ocorreu um erro ao criar o arquivo para exportação.");
        }
        // Chama a função para a criação do arquivo.
        $fileName = $this->obrigacoesService->createFileExportacao($row['NMARQUIVO'], $sef2Data, 'DSREGARQMAG');

        // Retorna o nome do arquivo exportado.
        return $fileName;
    }*/
    
    private function createFileSef2($row) {
        
        $spedData = [];
        // Verifica se há uma extensão já informada.
        $i = 0;
        $params = array(
            "NRORG"         => $row["NRORG"],
            "NRSEQARQMAG"   => $row["NRSEQARQMAG"],
            "INICIO"        => (5000*$i +1),
            "FIM"           => (5000*($i+1))
        );
        
        $spedData = $this->sef2Factory->getSef2FiscalDataPeriod($params);
        
        if(!empty($spedData)){
         
            if(empty(pathinfo($row["NMARQUIVO"], PATHINFO_EXTENSION)) || substr($row["NMARQUIVO"], -1) == '.') {
                // Se o nome do arquivo for terminado em '.', termina a extensão '.txt'.
                if (substr($row["NMARQUIVO"], -1) == '.') {
                    $row["NMARQUIVO"] .= "txt";
                }
                // Senão, adiciona a extensão '.txt' ao nome do arquivo.
                else {
                    $row["NMARQUIVO"] .= ".txt";
                }
            }
    
            // Cria ou sobrepõe um arquivo com o nome dado.
            try {
                $file = fopen(sys_get_temp_dir() . DIRECTORY_SEPARATOR . $row["NMARQUIVO"], "w");
            } catch (\Exception $e) {
                // Se houver algum erro ao tentar abrir o arquivo, lança uma exceção.
                throw new \Exception("Ocorreu um erro ao criar o arquivo para exportação.");
            }
            // Se houver algum erro após tentar abrir o arquivo, lança uma exceção.
            if (!$file) {
                throw new \Exception("Ocorreu um erro ao criar o arquivo para exportação.");
            }
            
            while(!empty($spedData)){
                
                $text = "";
                // Percorre os dados, concatenando na variável a ser impressa.
                foreach ($spedData as $dataRow) {
                    $text .= $dataRow["DSREGARQMAG"] . "\r\n";
                }
                
                // Imprime o texto no arquivo.
                $text = mb_convert_encoding($text, "UTF-8", "UTF-8");
                         
                fprintf($file, "%s", $text);
                
                $i = $i + 1;
                $params = array(
                    "NRORG" => $row["NRORG"],
                    "NRSEQARQMAG" => $row["NRSEQARQMAG"],
                    "INICIO" => (5000*$i +1),
                    "FIM" => (5000*($i+1))
                );
                
                $spedData = [];
                
                $spedData = $this->sef2Factory->getSef2FiscalDataPeriod($params);
                
            }
            
            fclose($file);
            
            return $row["NMARQUIVO"];
        } else {
            if(isset($row['NRAGENDAMENTO'])){
                $this->mensagemError = "Não há dados a serem exibidos.";
                return $fileName = false;
            } else {
                throw new \Exception("Não há dados a serem exibidos.");
            }
        }
    }

    /**
     * Função para a exportação SEF-2 Fiscal
     */
    public function exportarSef2($row)
    {
        // Valida os parâmetros associados.
        $this->validateSef2($row);
        
        if(isset($row['NRAGENDAMENTO']) && $this->geraArquivo == false){
            return false;
        }
        
        // Gera o código sequencial do arquivo magnético através do NOVOCODIGO.
        $row['NRSEQARQMAG'] = $this->obrigacoesService->getNextNrseqarqmag($row['NRORG']);

        // Monta o array com os parametros para chamar a procedure
        $params = [
            'CDEMPRESA'     => $row['CDEMPRESA'],
            'CDIMPOSTO'     => '00',
            'CDINSCESTA'    => $row['CDINSCESTA'],
            'DTINICIAL'     => $row['DTINICIAL'],
            'DTFINAL'       => $row['DTFINAL'],
            'LIVROMAG'      => $row['CDLIVROMAG'],
            'STSUFRAMA'     => (empty($row['STSUFRAMA']) || (!isset($row['STSUFRAMA']))) ? null : $row['STSUFRAMA'],
            'STARQUIVO'     => $row['STARQUIVO'],
            'STFINALIDADE'  => $row['STFINALIDADE'],
            'STREGINV'      => (empty($row["STREGINV"]) || (!isset($row["STREGINV"]))) ? "0" : $row["STREGINV"],
            'STOPISS'       => $row['STOPISS'],
            'STOPIPI'       => $row['STOPIPI'],
            'STVERSAO'      => str_replace(".", "", $row['STVERSAO']), 
            "NRSEQARQMAG"   => $row["NRSEQARQMAG"],
        ];

        // Chama a procedure de exportação
        $this->sef2Factory->callSef2FiscalProcedure($params);

        /**
         * Foi evitado utilizar um bloco finally devido à possível
         * incompativilidade com a versão do PHP
         */
        try
        {
            // Seta os parametros paar a exclusão dos dados temporários
            $params = [
                'NRORG' => $row['NRORG'],
                'NRSEQARQMAG' => $row['NRSEQARQMAG'],
            ];
            // Chama a função para gerar o arquivo texto
            $fileName = $this->createFileSef2($row);

            // Exclui os dados temporários da exportação no banco de dados
            $this->sef2Factory->deleteSef2FiscalData($params);

            // Retorna o nome do arquivo com suas possíveis modificações
            return $fileName;
        }
        catch(\Exception $e)
        {
            // Exclui os dados temporários da exportaçao no banco de dados
            $this->sef2Factory->deleteSef2FiscalData($params);
            throw $e;
        }

    }

    /**
     * Função para validação dos dados informados para o SEF-2
     */
    private function validateSef2($row)
    {
        if (isset($row['NRAGENDAMENTO'])){
            
            $this->mensagemError = '';
            
            // Verifica se o campo 'Empresa' possui algum vlr informado
            if(empty($row['CDEMPRESA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Empresa deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Empresa deve ser informada');
            }
            // Verifica se o campo 'Referência' possui algum vlr informado
            if(empty($row['DTREFINI'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Referência deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Referência deve ser informada');
            }
            // Verifica se o campo 'Nome do Arquivo' possui algum vlr informado
            if(empty($row['NMARQUIVO'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Nome do Arquivo deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception('Nome do Arquivo deve ser informado');
            }
            // Verifica se o campo 'Inscrição Estadual' possui algum vlr informado
            if(empty($row['CDINSCESTA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Incrição Estadual deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception('Incrição Estadual deve ser informado');
            }
            // Verifica se campo 'Formato de Arquivo' possui algum vlr informado
            if(empty($row['STARQUIVO'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Formato de Arquivo deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception('Formato de Arquivo deve ser informado');
            }
            // Verifica se campo 'Finalidade do Arquivo' possui algum vlr informado
            if(empty($row["STFINALIDADE"]) && !(isset($row["STFINALIDADE"]) && $row["STFINALIDADE"] == "0")){
                $this->mensagemError = $this->mensagemError.'<br />'.'Finalidade do Arquivo deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Finalidade do Arquivo deve ser informada');
            }
            // Verifica se o campo 'Registro de Inventário' possui algum vlr informado
            if(empty($row["STREGINV"]) && !(isset($row["STREGINV"]) && $row["STREGINV"] == "0")) {
                $this->mensagemError = $this->mensagemError.'<br />'.'Registro de Inventário deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception("Apuração Lucro Bruto deve ser informada.");
            }
            // Verifica se o campo 'Operações Sugeitas ao ISS' possui algum vlr informado
            if(empty($row["STOPISS"]) && !(isset($row["STOPISS"]) && $row["STOPISS"] == "0")) {
                $this->mensagemError = $this->mensagemError.'<br />'.'Operações Sugeitas ao ISS deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception("Apuração Lucro Bruto deve ser informada.");
            }
            // Verifica se o campo 'Operações Sugeitas ao IPI' possui algum vlr informado
            if(empty($row["STOPIPI"]) && !(isset($row["STOPIPI"]) && $row["STOPIPI"] == "0")) {
                $this->mensagemError = $this->mensagemError.'<br />'.'Operações Sugeitas ao IPI deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception("Apuração Lucro Bruto deve ser informada.");
            }
    
            /**
             * Busca e atribui os valores de NRORG e datas inicial e final do mẽs
             * à variável row
             */
            //$nrorg = $this->environment->getNrorg();
            $datas = $this->obrigacoesService->getFirstAndLastDays($row['DTREFINI']);
            $row['DTINICIAL'] = $datas['DTINICIAL'];
            $row['DTFINAL']= $datas['DTFINAL'];
            //$row['NRORG'] = $nrorg;
            
            // Seta o imposto a ser validado no mapa de apuração.
            $impostos = array('00');
            // Valida o mapa de apuração
            $mapaApuracIsValid = $this->obrigacoesService->mapaApuracIsValid($row, $impostos);
    
            // Verifica se o mapa está invalido, lançando um erro em caso positivo.
            if(!$mapaApuracIsValid){
                $this->mensagemError = $this->mensagemError.'<br />'.'Todos os mapas devem estar bloquados para a geração do arquivo.';
                $this->geraArquivo = false;
                //throw new \Exception('Todos os mapas devem estar bloquados para a geração do arquivo.');
            }
        }
        else {
            // Verifica se o campo 'Empresa' possui algum vlr informado
            if(empty($row['CDEMPRESA'])){
                throw new \Exception('Empresa deve ser informada');
            }
            // Verifica se o campo 'Referência' possui algum vlr informado
            if(empty($row['DTREFINI'])){
                throw new \Exception('Referência deve ser informada');
            }
            // Verifica se o campo 'Nome do Arquivo' possui algum vlr informado
            if(empty($row['NMARQUIVO'])){
                throw new \Exception('Nome do Arquivo deve ser informado');
            }
            // Verifica se o campo 'Inscrição Estadual' possui algum vlr informado
            if(empty($row['CDINSCESTA'])){
                throw new \Exception('Incrição Estadual deve ser informado');
            }
            // Verifica se campo 'Formato de Arquivo' possui algum vlr informado
            if(empty($row['STARQUIVO'])){
                throw new \Exception('Formato de Arquivo deve ser informado');
            }
            // Verifica se campo 'Finalidade do Arquivo' possui algum vlr informado
            if(empty($row["STFINALIDADE"]) && !(isset($row["STFINALIDADE"]) && $row["STFINALIDADE"] == "0")){
                throw new \Exception('Finalidade do Arquivo deve ser informada');
            }
            // Verifica se o campo 'Registro de Inventário' possui algum vlr informado
            if(empty($row["STREGINV"]) && !(isset($row["STREGINV"]) && $row["STREGINV"] == "0")) {
                throw new \Exception("Apuração Lucro Bruto deve ser informada.");
            }
            // Verifica se o campo 'Operações Sugeitas ao ISS' possui algum vlr informado
            if(empty($row["STOPISS"]) && !(isset($row["STOPISS"]) && $row["STOPISS"] == "0")) {
                throw new \Exception("Apuração Lucro Bruto deve ser informada.");
            }
            // Verifica se o campo 'Operações Sugeitas ao IPI' possui algum vlr informado
            if(empty($row["STOPIPI"]) && !(isset($row["STOPIPI"]) && $row["STOPIPI"] == "0")) {
                throw new \Exception("Apuração Lucro Bruto deve ser informada.");
            }
        
            /**
             * Busca e atribui os valores de NRORG e datas inicial e final do mẽs
             * à variável row
             */
            $nrorg = $this->environment->getNrorg();
            $datas = $this->obrigacoesService->getFirstAndLastDays($row['DTREFINI']);
            $row['DTINICIAL'] = $datas['DTINICIAL'];
            $row['DTFINAL']= $datas['DTFINAL'];
            $row['NRORG'] = $nrorg;
        
            // Seta o imposto a ser validado no mapa de apuração.
            $impostos = array('00');
            // Valida o mapa de apuração
            $mapaApuracIsValid = $this->obrigacoesService->mapaApuracIsValid($row, $impostos);
        
            // Verifica se o mapa está invalido, lançando um erro em caso positivo.
            if(!$mapaApuracIsValid){
                throw new \Exception('Todos os mapas devem estar bloquados para a geração do arquivo.');
            }
        }
    }
    
    
    public function findAgendamento() {
        // Busca os parâmetros conforme empresa e nrorg.
        $agendamento = $this->sef2Factory->findAgendamento();

        return $agendamento;
    }
    
    public function saveAgendamento($row) {
        try {
            
            $row['CDTELA'] = 'FIS47000';
            
            $dtinicial  = DateUtil::getPrimeiroDiaDoMes( $this->formataData($row['DTREFINI']));
            $dtfinal    = DateUtil::getUltimoDiaDoMes( $this->formataData($row['DTREFINI']));
            $dtinicial = $dtinicial->format("d/m/Y");
            $dtfinal = $dtfinal->format("d/m/Y");
    
            $row["DTINICIAL"] = $dtinicial;
            $row["DTFINAL"] = $dtfinal;
            
            //var_dump($row);
            //throw new \Exception('ioioioioioi');
            
            if(isset($row['__is_new']) && $row['__is_new'] == true){
                $row["NRAGENDAMENTO"] = $this->newCode->getCodeByTableName('NRAGENDAMENTO', $row["NRORG"], 1, 10);
            }
            
            if($row['CDINSCESTA'] == 'T'){
                $arrayInscEsta = $this->sef2Factory->getInscEsta($row);
                $cdinscesta = '_';
                
                foreach($arrayInscEsta as $value){
                    $cdinscesta = $cdinscesta.$value['CDINSCESTA'].'_';
                }
                
                $row['CDINSCESTA'] = $cdinscesta;
            } else if(is_array($row['CDINSCESTA']) == true){
                $arrayInscEsta = $row['CDINSCESTA'];
                $cdinscesta = '_';
                
                foreach($arrayInscEsta as $value){
                    $cdinscesta = $cdinscesta.$value.'_';
                }
                
                $row['CDINSCESTA'] = $cdinscesta;
            } 
        
            if(isset($row['__is_new']) && $row['__is_new'] == true){
                $this->sef2Factory->insertAgendamento($row);
            } else {
                $this->sef2Factory->updateAgendamento($row);
                
                 $arquivos = $this->sef2Factory->getAgendamentoArquivo($row);
                
                if($arquivos){
                    foreach($arquivos as $arquivo){
                        unlink($arquivo['NMPATHARQ']);
                    }
                    
                    $this->sef2Factory->deleteAgendamentoArquivo($arquivo);
                }
                
                $idstatus = 'P';
                $this->sef2Factory->updateAgendamentoIdStatus($row, $idstatus);
                
            }
            
            $agendamento = $this->sef2Factory->getAgendamentoInsert($row);
            
            if($agendamento){
                
                $agendamento['NRORG'] = $row['NRORG'];
                $getConfigSMTP = $this->sef2Factory->getConfiguraSMTP($agendamento)[0];
                if(isset($row['__is_new']) && $row['__is_new'] == true){
                    $nomeJob = $row['CDTELA'].'_'.$row['NRAGENDAMENTO'];
                } else {
                    $nomeJob = $row['CDTELA'].'_'.str_pad($row['NRAGENDAMENTO'], 10, "0", STR_PAD_LEFT);
                }
                $dataContabAuto = $row['DTAGENDAMENTO'];
                $sequencialJob = $row['NRAGENDAMENTO'];
                $nrorg = $row['NRORG'];
                $descricao = $row['CDTELA'].' - SEF II (Pernambuco)'.'. Exportação das declarações Acessórias de forma automática na data de '.$row['DTAGENDAMENTO'];
                //Conferir caminho do diretorio do xampp
                $arqCallService = $getConfigSMTP['CALLSERVPATH'];//'C:\Teknisa\CallService.php';
                //$dirphp = str_replace('/','\',$DIRPHP);
                $dirphp = $getConfigSMTP['DIRPHP'];//'C:/xampp/php';
                $jenkinsPath = $getConfigSMTP['JENKINSPATH'];//'http://192.168.120.132:8080/';
                $execPath = '/execAgendamentoSef2';
                $periodicidade = $row['IDPERIAGEN'];
                $jenkinsCreateItem = $getConfigSMTP['JENKCREATITEM'];
                $this->agendamento->criaJob($nomeJob, $dataContabAuto, $sequencialJob, $nrorg, $descricao, $arqCallService, $dirphp, $jenkinsPath, $execPath, $periodicidade, $jenkinsCreateItem);
                
            }
            
        } catch(\Exception $e) {
            //
            throw $e;
        }
    }
    
    public function execAgendamento($row){
        try{
            $agendamento = $this->sef2Factory->findAgendamentoExec($row)[0];
            
            $findParamDeclAcess = $this->sef2Factory->findParamDeclAcess($agendamento);
            
            $agendamento['STSUFRAMA'] = isset($findParamDeclAcess['STSUFRAMA']) ? $findParamDeclAcess['STSUFRAMA'] : null;
            $agendamento['STVERSAO'] = isset($findParamDeclAcess['STVERSAO']) ? $findParamDeclAcess['STVERSAO'] : null;
            $agendamento['STFINALIDADE'] = isset($findParamDeclAcess['STFINALIDADE']) ? $findParamDeclAcess['STFINALIDADE'] : null;
            $agendamento['STREGINV'] = isset($findParamDeclAcess['STREGINV']) ? $findParamDeclAcess['STREGINV'] : null;
            $agendamento['STOPIPI'] = isset($findParamDeclAcess['STOPIPI']) ? $findParamDeclAcess['STOPIPI'] : null;
            $agendamento['STARQUIVO'] = isset($findParamDeclAcess['STARQUIVO']) ? $findParamDeclAcess['STARQUIVO'] : null;
            $agendamento['STOPISS'] = isset($findParamDeclAcess['STOPISS']) ? $findParamDeclAcess['STOPISS'] : null;
            
            if($agendamento){
                $this->mensagemBody = '';
                
                $agendamento["NRORG"] = $row['NRORG'];
                
                $agendamento["DTEXECAGEND"] = $agendamento["DTATUAL"];
                
                $agendamento["DTREFINI"] = explode(' ', $agendamento["DTREFINI"])[0];
                
                //Necessário Fazer a verificação
                
                $agendamento['CDINSCESTAARRAY'] = $agendamento['CDINSCESTA'];
                $arrayInscEsta = explode('_',$agendamento['CDINSCESTAARRAY']);
                
                $getConfigSMTP = $this->sef2Factory->getConfiguraSMTP($agendamento)[0];
                $getContatos = $this->sef2Factory->getContatos($agendamento);
                
                $mail = new PHPMailer;
                $mail->CharSet = 'UTF-8';
                $mail->isSMTP();                        // Set mailer to use SMTP
                $mail->isHTML();
                $mail->Host = $getConfigSMTP['SERVIDORSMTP'];       // Specify main and backup SMTP servers
                $mail->SMTPAuth = true;                 // Enable SMTP authentication
                $mail->Username = $getConfigSMTP['LOGINSMTP'];    // SMTP username
                $mail->Password = $getConfigSMTP['SENHASMTP'];    // SMTP password
                $mail->From = $getConfigSMTP['LOGINSMTP'];
                $mail->FromName = 'ERP Pebbian';
                $mail->Subject = 'SEF II (Pernambuco) de '.$agendamento['DTAGENDAMENTO'];
                // $mail->addAddress($cliente['DSEMAILCLIE']);
                // $mail->addAddress($vendedor['DSEMAILOPER']);
                
                foreach($getContatos as $contato){
                    $mail->addAddress($contato['EMAIL']);
                };
                
                $agendamento["NMEMPRESA"] = $this->sef2Factory->getNmEmpresa($agendamento)["NMEMPRESA"];
                        
                $this->mensagemBody = 'Caro cliente, '.'<br />'.'<br />';
                $this->mensagemBodySucess = 'Arquivo de SEF II (Pernambuco) gerado com Sucesso!'
                .'<br />'.'Empresa: '.$agendamento['CDEMPRESA'].' - '.$agendamento['NMEMPRESA'];
                $this->mensagemErrorBody = 'Erro ao gerar o arquivo de SEF II (Pernambuco):'.'<br />'.'<br />'
                .'<br />'.'Empresa: '.$agendamento['CDEMPRESA'].' - '.$agendamento['NMEMPRESA'];
                
                
                $contErro = 0;
                $contSucess = 0;
                
                foreach( $arrayInscEsta as $inscEsta ){
                    if(isset($inscEsta) && $inscEsta != ''){
                        
                       $this->geraArquivo = true;
                            
                        $dataName = str_replace('/', '', explode(' ', $agendamento["DTATUAL"])[0]);
                        $horaName = str_replace(':', '', explode(' ', $agendamento["DTATUAL"])[1]);
                        
                        if($agendamento['IDPERIAGEN'] == '0'){
                            $dtinicial = $agendamento["DTINICIAL"];
                            $dtfinal = $agendamento["DTFINAL"];
                        } else 
                        if($agendamento['IDPERIAGEN'] == '1'){
                            $dtinicial  = DateUtil::getPrimeiroDiaDoMes( $this->formataData(explode(' ', $agendamento["DTATUAL"])[0]));
                            $dtfinal    = DateUtil::getUltimoDiaDoMes( $this->formataData(explode(' ', $agendamento["DTATUAL"])[0]));
                            $dtinicial = $dtinicial->format("d/m/Y");
                            $dtfinal = $dtfinal->format("d/m/Y");
                        } else 
                        if($agendamento['IDPERIAGEN'] == '2'){
                            $dtinicial  = DateUtil::getPrimeiroDiaDoMes( $this->formataData(explode(' ', $agendamento["LAST_MONTH"])[0]));
                            $dtfinal    = DateUtil::getUltimoDiaDoMes( $this->formataData(explode(' ', $agendamento["LAST_MONTH"])[0]));
                            $dtinicial = $dtinicial->format("d/m/Y");
                            $dtfinal = $dtfinal->format("d/m/Y");
                        }
                        
                        $agendamento["DTINICIAL"] = $dtinicial;
                        $agendamento["DTFINAL"] = $dtfinal;
                        
                        $agendamento['CDINSCESTA'] = $inscEsta;
                        $agendamento["NMARQUIVO"] = $agendamento['CDTELA'].$agendamento['NRAGENDAMENTO'].'_'.$inscEsta.'_'.$dataName.$horaName;
                          
                        $fileName = $this->exportarSef2($agendamento);
                        
                        if($this->mensagemError == ''){
                            $this->mensagemBodySucess = $this->mensagemBodySucess
                            .'<br />'.'Inscrição Estadual: '.$agendamento['CDINSCESTA'];
                            ++$contSucess;
                            
                        } else {
                            $this->mensagemErrorBody = $this->mensagemErrorBody
                            .'<br />'.'Inscrição Estadual: '.$agendamento['CDINSCESTA']
                            .$this->mensagemError.'<br />'.'<br />';
                            ++$contErro;
                        }
                        
                        if($fileName){
                            $file = sys_get_temp_dir() . DIRECTORY_SEPARATOR . $fileName;
                            $agendamento["NMPATHARQ"] = $file ;
                            
                            $verifArq = $this->sef2Factory->verAgendamentoArquivo($agendamento);
                            
                            if(empty($verifArq)){
                                $agendamento["NRARQUIVO"] = $this->newCode->getCodeByTableName('NRARQUIVO', $agendamento["NRORG"], 1, 10);
                                $this->sef2Factory->insertAgendamentoArquivo($agendamento);
                            }
                        }
                
                    }
                }
                
                if(($contErro > 0) && ($contSucess > 0)){
                    $mail->Body = $this->mensagemBody.'<br />'.$this->mensagemBodySucess.'<br />'.'<br />'
                    .'---------------------------------------------------------------------'.'<br />'
                    .$this->mensagemErrorBody
                    .'<br />'.'Atenciosamente,'.'<br />'.'<br />'.'Equipe ERP Pebbian.';
                    $mail->send();
                } 
                else if($contErro > 0){
                    $mail->Body = $this->mensagemBody.'<br />'
                    .$this->mensagemErrorBody
                    .'<br />'.'Atenciosamente,'.'<br />'.'<br />'.'Equipe ERP Pebbian.';
                    $mail->send();
                }
                else if($contSucess > 0){
                    $mail->Body = $this->mensagemBody.'<br />'.$this->mensagemBodySucess.'<br />'
                    .'<br />'.'Atenciosamente,'.'<br />'.'<br />'.'Equipe ERP Pebbian.';
                    $mail->send();
                }
                
                $idstatus = 'R';
                $this->sef2Factory->updateAgendamentoIdStatus($agendamento, $idstatus);
                
            }
        
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function deleteAgendamento($row){
        try {    
            
            $agendamento = $this->sef2Factory->getAgendamentoInsert($row)[0];
            
            
            if($agendamento){
                $nomeJob = $agendamento['CDTELA'].'_'.str_pad($agendamento['NRAGENDAMENTO'], 10, "0", STR_PAD_LEFT);
                $getConfigSMTP = $this->sef2Factory->getConfiguraSMTP($agendamento)[0];
                
                $this->agendamento->apagaJob($nomeJob, null, $getConfigSMTP['JENKINSPATH'], $getConfigSMTP["CALLSERVPATH"]);
                
                $arquivos = $this->sef2Factory->getAgendamentoArquivo($agendamento);
                
                if($arquivos){
                    foreach($arquivos as $arquivo){
                        unlink($arquivo['NMPATHARQ']);
                    }
                    
                    $this->sef2Factory->deleteAgendamentoArquivo($arquivo);
                    $this->sef2Factory->deleteAgendamento($arquivo);
                    
                } else {
                    $this->sef2Factory->deleteAgendamento($agendamento);
                }
                
            }
            
        } catch(\Exception $e) {
            //
            throw $e;
        }
                
    }
 
    private function formataData($data) {
        if (!$data) {
            return null;
        }

        // Verifica se está com o formato de data-hora.
        if (strlen($data) == 19) {
            $data = DateUtil::truncateString($data);
        }
        $data = DateUtil::getDataDeString($data);
        $data = DateUtil::truncateData($data);

        return $data;
    }
    
}